==> haskell-gi-gtk-hs-0.3.17-90-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gi-gtk-hs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gi-gtk-hs
version:              0.3.17
visibility:           public
id:                   gi-gtk-hs-0.3.17-8hMdeCABl5kchMEvcooiU
key:                  gi-gtk-hs-0.3.17-8hMdeCABl5kchMEvcooiU
license:              LGPL-2.1-only
maintainer:           mail@jonasplatte.de
author:
    Jonas Platte,
    Duncan Coutts,
    Axel Simon,
    Hamish Mackenzie,
    Iñaki García Etxebarria

homepage:             https://github.com/haskell-gi/haskell-gi
synopsis:
    A wrapper for gi-gtk, adding a few more idiomatic API parts on top

description:
    A wrapper for gi-gtk, adding a few more idiomatic API parts on top

category:             Graphics
abi:                  127db19d555a667b99332a97800c81db
exposed:              True
exposed-modules:
    Data.GI.Gtk Data.GI.Gtk.BuildFn Data.GI.Gtk.ComboBox
    Data.GI.Gtk.ModelView.CellLayout Data.GI.Gtk.ModelView.CustomStore
    Data.GI.Gtk.ModelView.ForestStore Data.GI.Gtk.ModelView.SeqStore
    Data.GI.Gtk.ModelView.TreeModel Data.GI.Gtk.ModelView.Types
    Data.GI.Gtk.Threading Data.GI.Gtk.Widget

import-dirs:          /usr/lib/ghc-9.6.6/site-local/gi-gtk-hs-0.3.17
library-dirs:         /usr/lib/ghc-9.6.6/site-local/gi-gtk-hs-0.3.17
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/gi-gtk-hs-0.3.17
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gi-gtk-hs
hs-libraries:         HSgi-gtk-hs-0.3.17-8hMdeCABl5kchMEvcooiU
depends:
    base-4.18.2.1 base-compat-0.14.1-4heBy5B59ewBpEOwRrJlc4
    containers-0.6.7 gi-gdk-3.0.29-9Cio5PmYaBOLfDxrg6IRkZ
    gi-gdkpixbuf-2.0.32-Htg6DGuwaMcFL2g7N2ZMWr
    gi-glib-2.0.30-3k4vmQVPL9RLQYzuHWwzT2
    gi-gobject-2.0.31-5tr4HFcIhsRKyCfw0IN2gB
    gi-gtk-3.0.43-ItvzSU2O6bM1eqCaiH2XXx
    haskell-gi-base-0.26.9-9dGlnSJnubc2h9MiqHeprA mtl-2.3.1 text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-gi-gtk-hs/html/gi-gtk-hs.haddock
haddock-html:         /usr/share/doc/haskell-gi-gtk-hs/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gi-gtk-hs-0.3.17-91-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gi-gtk-hs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gi-gtk-hs
version:              0.3.17
visibility:           public
id:                   gi-gtk-hs-0.3.17-4vaCjl1Efzx5Mqj1MRvhLp
key:                  gi-gtk-hs-0.3.17-4vaCjl1Efzx5Mqj1MRvhLp
license:              LGPL-2.1-only
maintainer:           mail@jonasplatte.de
author:
    Jonas Platte,
    Duncan Coutts,
    Axel Simon,
    Hamish Mackenzie,
    Iñaki García Etxebarria

homepage:             https://github.com/haskell-gi/haskell-gi
synopsis:
    A wrapper for gi-gtk, adding a few more idiomatic API parts on top

description:
    A wrapper for gi-gtk, adding a few more idiomatic API parts on top

category:             Graphics
abi:                  ada894c105766c0904ce884bc2c8f8ee
exposed:              True
exposed-modules:
    Data.GI.Gtk Data.GI.Gtk.BuildFn Data.GI.Gtk.ComboBox
    Data.GI.Gtk.ModelView.CellLayout Data.GI.Gtk.ModelView.CustomStore
    Data.GI.Gtk.ModelView.ForestStore Data.GI.Gtk.ModelView.SeqStore
    Data.GI.Gtk.ModelView.TreeModel Data.GI.Gtk.ModelView.Types
    Data.GI.Gtk.Threading Data.GI.Gtk.Widget

import-dirs:          /usr/lib/ghc-9.6.6/site-local/gi-gtk-hs-0.3.17
library-dirs:         /usr/lib/ghc-9.6.6/site-local/gi-gtk-hs-0.3.17
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/gi-gtk-hs-0.3.17
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gi-gtk-hs
hs-libraries:         HSgi-gtk-hs-0.3.17-4vaCjl1Efzx5Mqj1MRvhLp
depends:
    base-4.18.2.1 base-compat-0.14.1-4heBy5B59ewBpEOwRrJlc4
    containers-0.6.7 gi-gdk-3.0.29-FALrD5OsFlCI4Q3UCF1y8U
    gi-gdkpixbuf-2.0.32-DZSprOVcllBH0WFQ8euba5
    gi-glib-2.0.30-JB0GMONdmOUDhzu6OQDKxH
    gi-gobject-2.0.31-2J6unekNIU1AJ1OAEncjaU
    gi-gtk-3.0.43-6cLzVWds3AJJ3Ti3kelaYb
    haskell-gi-base-0.26.9-9dGlnSJnubc2h9MiqHeprA mtl-2.3.1 text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-gi-gtk-hs/html/gi-gtk-hs.haddock
haddock-html:         /usr/share/doc/haskell-gi-gtk-hs/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
